helpers
------------------------

.. automodule:: flax.nnx
.. currentmodule:: flax.nnx

.. autoclass:: Dict
   :members:
.. autoclass:: List
   :members:
.. autoclass:: Sequential
   :members:
.. autoclass:: TrainState
   :members: